@@ -5,8 +5,8 @@
 ;; Author: Daniel Mendler <mail@daniel-mendler.de>
 ;; Maintainer: Daniel Mendler <mail@daniel-mendler.de>
 ;; Created: 2021
-;; Package-Version: 20260118.746
-;; Package-Revision: fbbcdf9578a8
+;; Package-Version: 20260127.1325
+;; Package-Revision: 1d8cf388c842
 ;; Package-Requires: ((emacs "29.1") (compat "30"))
 ;; URL: https://github.com/minad/corfu
 ;; Keywords: abbrev, convenience, matching, completion, text
@@ -421,6 +421,7 @@ the initial completion state.  PREFIX is the minimum prefix length."
 ;; Not present on non-gtk/non-x builds
 (defvar x-gtk-resize-child-frames)
 (defvar x-fast-protocol-requests)
+(defvar x-wait-for-event-timeout)
 
 ;; Function adapted from posframe.el by tumashu
 (defun corfu--make-frame (frame x y width height)
@@ -433,6 +434,7 @@ FRAME is the existing frame."
   (let* ((window-min-height 1)
          (window-min-width 1)
          (inhibit-redisplay t)
+         (x-wait-for-event-timeout)
          (x-fast-protocol-requests t)
          (x-gtk-resize-child-frames corfu--gtk-resize-child-frames)
          (before-make-frame-hook)
